##  Introduction
Netskope delivers real-time visibility into data and provides robust threat protection when accessing cloud services, websites, and private applications. Once the Netskope integration is configured, SAP LeanIX uses Netskope to discover the SaaS applications used within your organization.
**Note**
If you intend to manually review and link each discovered application to fact sheets, deactivate automatic linking in the SaaS discovery inbox settings before configuring the integration. For details, see [Automatic Linking of Discovered Applications to Fact Sheets](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c41a87a441014aa86ff57b7a5198f__automatic_linking).
